
:orphan:

.. _sphx_glr_sg_execution_times:


Computation times
=================
**00:25.322** total execution time for 9 files **from all galleries**:

.. container::

  .. raw:: html

    <style scoped>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/5.3.0/css/bootstrap.min.css" rel="stylesheet" />
    <link href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css" rel="stylesheet" />
    </style>
    <script src="https://code.jquery.com/jquery-3.7.0.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
    <script type="text/javascript" class="init">
    $(document).ready( function () {
        $('table.sg-datatable').DataTable({order: [[1, 'desc']]});
    } );
    </script>

  .. list-table::
   :header-rows: 1
   :class: table table-striped sg-datatable

   * - Example
     - Time
     - Mem (MB)
   * - :ref:`sphx_glr_auto_examples_02_eddy-lifetime_fit.py` (``../../examples/02_eddy-lifetime_fit.py``)
     - 00:25.322
     - 0.0
   * - :ref:`sphx_glr_auto_examples_01_basic_mann_parameters_fit.py` (``../../examples/01_basic_mann_parameters_fit.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_auto_examples_03_eddy-lifetime_fit_3term_loss.py` (``../../examples/03_eddy-lifetime_fit_3term_loss.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_auto_examples_04_eddy-lifetime_fit_gelu.py` (``../../examples/04_eddy-lifetime_fit_gelu.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_auto_examples_05_custom_noisy_data_fit.py` (``../../examples/05_custom_noisy_data_fit.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_auto_examples_06_custom_data_interpolate_and_fit.py` (``../../examples/06_custom_data_interpolate_and_fit.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_auto_examples_07_mann_linear_regression.py` (``../../examples/07_mann_linear_regression.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_auto_examples_08_mann_box_generation_IEC.py` (``../../examples/08_mann_box_generation_IEC.py``)
     - 00:00.000
     - 0.0
   * - :ref:`sphx_glr_auto_examples_09_drd_box.py` (``../../examples/09_drd_box.py``)
     - 00:00.000
     - 0.0
